"""Cursor for ClickZetta DB-API."""

import collections
from collections import abc as collections_abc
import copy
import logging
import re

from clickzetta.enums import *

_LOGGER = logging.getLogger(__name__)


class Cursor(object):
    def __init__(self, connection):
        self.connection = connection
        self.description = None
        self.rowcount = -1
        self._query_result = None
        self._query_data = None
        self._closed = False

    def close(self):
        self._closed = True

    def _set_rowcount(self, query_result):

        self.rowcount = query_result.total_row_count

    def execute(self, operation: str, parameters=None):

        self._execute(operation, parameters)

    def _execute(
            self, operation: str, parameters
    ):
        self._query_data = None
        self._query_job = None
        client = self.connection._client

        if operation.startswith('select') or operation.startswith('SELECT'):
            self._query_result = client.select_table(client.token, operation)
        elif operation.startswith('drop') or operation.startswith("DROP"):
            self._query_result = client.drop_table(client.token, operation)
        elif operation.startswith('create') or operation.startswith("CREATE"):
            self._query_result = client.create_table(client.token, operation)
        elif operation.startswith('alter') or operation.startswith('ALTER'):
            self._query_result = client.alter_table(client.token, operation)
        elif operation.startswith('truncate') or operation.startswith("TRUNCATE"):
            self._query_result = client.truncate_table(client.token, operation)
        elif operation.startswith('show') or operation.startswith('SHOW'):
            self._query_result = client.show_table(client.token, operation)

        self._set_rowcount(self._query_result)
        self._query_data = self._query_result.data

    def executemany(self, operations, methods):
        print("not supported yet")

    def fetchone(self):
        try:
            return self._query_data.fetch_one()
        except StopIteration:
            return None

    def fetchmany(self, size=None):
        try:
            result = self._query_data.fetch_many(size)
            return '\n'.join(result)
        except StopIteration:
            return None

    def fetchall(self):
        result = self._query_data.fetch_all()
        return '\n'.join(result)

    def setinputsizes(self, sizes):
        """No-op, but for consistency raise an error if cursor is closed."""

    def setoutputsize(self, size, column=None):
        """No-op, but for consistency raise an error if cursor is closed."""

    def __iter__(self):
        return iter(self._query_data)
