import string
import base64
import numpy


class QueryData(object):
    def __init__(self, data: list):
        self.data = data

    def fetch_one(self) -> string:
        return self.data[0]

    def fetch_many(self, size: int) -> list:
        return self.data[0:size]

    def fetch_all(self):
        return self.data


class QueryResult(object):
    def __init__(self, total_msg: string):
        self.data = None
        self.state = None
        self.total_row_count = 0
        self.total_msg = total_msg
        self.fields = []
        self.data_types = []
        self._parse_result_data()

    def get_result_state(self) -> string:
        return self.total_msg['status']['state']

    def _parse_result_data(self):
        self.state = self.total_msg['status']['state']
        result_data = self.total_msg['resultSet']['data']['data'][0]
        decode_data = base64.b64decode(result_data).strip().decode('utf-8').replace('\\', '').replace('\\n', '')
        data_list = decode_data.split('\n')
        self.total_row_count = len(data_list)
        fields = self.total_msg['resultSet']['metadata']['fields']
        for field in fields:
            self.fields.append(field['name'])
            self.data_types.append(field['type']['category'])
        if len(self.fields) != len(self.data_types):
            AssertionError('query result field size is not equal with data_types size.')
        if len(self.fields) != len(data_list[0].split(',')):
            AssertionError('query result field size is not equal with return data column size')
        result_data = []
        for row in data_list:
            result_data.append(row)
        self.data = QueryData(result_data)
